<?php
/***************************************************************************
 *  					Theme Functions
 * 	----------------------------------------------------------------------
 * 						DO NOT EDIT THIS FILE
 *	----------------------------------------------------------------------
 *
 *  					Copyright (C) Themify
 * 						https://themify.me
 *
 *  To add custom PHP functions to the theme, create a child theme (https://themify.me/docs/child-theme) and add it to the child theme functions.php file.
 *  They will be added to the theme automatically.
 *
 ***************************************************************************/

/////// Actions ////////
// Init post, page and additional post types if they exist
add_action( 'after_setup_theme', 'themify_theme_init_types' );
if(themify_load_content_only()){
    // Enqueue scripts and styles required by theme
    add_action( 'wp_enqueue_scripts', 'themify_theme_enqueue_scripts', 11 );
    if(!themify_is_ajax_response()){
        add_action('wp_enqueue_scripts', 'themify_theme_ajax_enqueue_scripts',1);
    }
    // Browser compatibility
    add_action( 'wp_head', 'themify_viewport_tag' );

    // Register custom menu
    add_action( 'init', 'themify_register_custom_nav');

    // Ajax Loading
    add_action( 'init', 'themify_ajax_response');

    /////// Filters ////////
    add_filter( 'themify_parallax_header', 'themify_disable_parallax_header_on_mobile' );
	
	// Set class on body tag according to layout width
	add_filter( 'body_class', 'themify_theme_body_class', 99 );

    add_action('admin_enqueue_scripts', 'themify_admin_enqueue_scripts');
}

// Register sidebars
add_action( 'widgets_init', 'themify_theme_register_sidebars' );

// Exclude CPT for sidebar
add_filter( 'themify_exclude_CPT_for_sidebar', 'themify_CPT_exclude_sidebar' );

/**
 * Enqueue Stylesheets and Scripts
 * @since 1.0.0
 */
function themify_theme_enqueue_scripts() {
	global $themify;

	// Get theme version for Themify theme scripts and styles
	$theme_version = wp_get_theme()->display( 'Version' );
	$header = themify_theme_get_header_design();
	
	///////////////////
	//Enqueue styles
	///////////////////

	// Themify base styling
	wp_enqueue_style( 'theme-style', themify_enque( THEME_URI . '/style.css' ), array(), $theme_version );

	// Themify Media Queries CSS
	wp_enqueue_style( 'themify-media-queries', themify_enque(THEME_URI . '/media-queries.css'), array(), $theme_version);

	if( $header !== '' && $header !== 'default' && $header !== 'header-none'  && $header !== 'header-horizontal'  ) {
		wp_enqueue_style( 'music-header-'.$header, themify_enque(THEME_URI . '/styles/' . $header . '.css'), array( 'theme-style' ) );
	}
	wp_enqueue_script( 'themify-backstretch', themify_enque(THEMIFY_URI.'/js/backstretch.themify-version.js'), array('jquery'), false, true );

	// Themify child base styling
	if( is_child_theme() ) {
		wp_enqueue_style( 'theme-style-child', themify_enque( get_stylesheet_uri() ), array(), $theme_version );
	}

	///////////////////
	//Enqueue scripts
	///////////////////

	// Enqueue media element in pages that will load album in lightbox
	wp_enqueue_style( 'wp-mediaelement' );
	wp_enqueue_script( 'wp-mediaelement' );

	// Masonry
	wp_enqueue_script( 'themify-masonry', THEME_URI . '/js/jquery.masonry.min.js', array(), $theme_version, true );

	// Slide mobile navigation menu
	wp_enqueue_script( 'slide-nav', themify_enque(THEMIFY_URI . '/js/themify.sidemenu.js'), array( 'jquery' ), $theme_version, true );

	// Auto Height iframe plugin
	wp_enqueue_script( 'auto-height-iframe', THEME_URI . '/js/jquery.iframe-auto-height.min.js', array('jquery'), false, true );

	// Themify custom lightbox
	wp_enqueue_script( 'themibox', themify_enque(THEME_URI . '/js/themibox.js'), array('jquery'), $theme_version, true );

	// Dominant Color
	wp_enqueue_script( 'themify-dominant-color', THEME_URI . '/js/jquery.dominant-color.min.js', array(), $theme_version, true );
	// Themify internal scripts
	wp_enqueue_script( 'theme-script',	themify_enque(THEME_URI . '/js/themify.script.js'), array('jquery'), $theme_version, true );


	// Prepare JS variables
	$themify_script_vars = array(
		'themeURI' => THEME_URI,
		'lightbox' => themify_lightbox_vars_init(),
		'fixedHeader' 	=> themify_check('setting-fixed_header_disabled')? '': 'fixed-header',
		'ajax_nonce'	=> wp_create_nonce('ajax_nonce'),
		'ajax_url'		=> admin_url( 'admin-ajax.php' ),
		'is_ajax'=>!themify_check('setting-disable_ajax'),
		// Screen size at which horizontal menu is moved into side panel
		'smallScreen' => '760',
		// Resize refresh rate
		'resizeRefresh' => '250',
		// Video File ratio
		'videoRatio' => '1.777777777777778',
		'parallaxHeader' => apply_filters( 'themify_parallax_header', true ),
		// Themify Custom Lightbox
		'themibox' => array(
			'close' => '<i class="close-lightbox ti-close"></i>',
		),

		// Auto play audio
		'autoplay' => themify_check( 'setting-audio_player_autoplay' ) ? 'autoplay' : '',

		// Enable album lightbox
		'albumLightbox' => 'true',
			'fixedHeaderHeightCons' => 74,
			
			// Back to Top
		'back_top' => '<a class="floating-back-top floating-back-top-hide" href="#header"><span>' . esc_html__( 'Back to top', 'themify' ) . '</span></a>'
	);

	if ( $themify_script_vars['is_ajax'] ) {
		$themify_script_vars['disable_link'] = array(
			'feed_url'=> esc_attr(get_bloginfo( 'rss2_url' )),
			'comments_rss'=> esc_attr(get_bloginfo( 'comments_rss2_url' )),
			'login_url'=> wp_login_url(),
			'logout_url'=> wp_logout_url(),
			'admin_url'=> admin_url(),
		);
		$themify_script_vars['site_url'] = get_site_url();
		$ext = wp_get_mime_types();
		unset($ext['htm|html']);
		$themify_script_vars['ext'] =implode(array_keys($ext),'|');
	}

	// Collect page variables or use defaults
	$page_id = get_queried_object_id();
	if( $page_id != null || themify_is_shop() ) {
		$slider_play = themify_get( 'background_auto', themify_check('setting-footer_slider_auto') ? themify_get('setting-footer_slider_auto') : 'yes' );
		$slider_autoplay = themify_get( 'background_autotimeout', themify_check('setting-footer_slider_autotimeout') ? themify_get('setting-footer_slider_autotimeout') : 5 );
		$slider_speed = themify_get( 'background_speed', themify_check('setting-footer_slider_speed') ? themify_get('setting-footer_slider_speed') : 500 );
		$slider_wrap = themify_get( 'background_wrap', 'yes' );
		$slider_background_mode = themify_get( 'background_mode', 'cover' );
		$slider_background_position = themify_get( 'background_position', 'center-center' );
	} else {
		$slider_play = 'yes';
		$slider_autoplay = 5;
		$slider_speed = 500;
		$slider_wrap = 'yes';
		$slider_background_mode = 'cover';
		$slider_background_position = 'center-center';
	}
		
	// Header gallery
	wp_enqueue_script( 'themify-header-slider', themify_enque(THEME_URI . '/js/themify.header-slider.js'), array( 'jquery' ), false, true );
	
	//Inject variable values in gallery script
	wp_localize_script( 'themify-header-slider', 'themifyVars', array(
			'play'					=> $slider_play,
			'autoplay'				=> $slider_autoplay,
			'speed'					=> $slider_speed,
			'wrap'					=> $slider_wrap,
			'backgroundMode'		=> $slider_background_mode,
			'backgroundPosition'	=> $slider_background_position
		)
	);

	// Inject variable values in gallery script
	wp_localize_script( 'theme-script', 'themifyScript', apply_filters('themify_script_vars', $themify_script_vars ) );

	// WordPress internal script to move the comment box to the right place when replying to a user
	if ( is_single() || is_page() ) wp_enqueue_script( 'comment-reply' );
}

/**
 * Load Google fonts used by the theme
 *
 * @return array
 */
function themify_theme_google_fonts( $fonts ) {
	/* translators: If there are characters in your language that are not supported by Lato, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Lato font: on or off', 'themify' ) ) {
		$fonts['lato'] = 'Lato:100,300,400,700,900';
	}

	return $fonts;
}
add_filter( 'themify_google_fonts', 'themify_theme_google_fonts' );

/**
 * Checks if .animated-bg class must be output and sets the first animation color as initial background
 * Displays the data-bg and class attributes, including the background image and fullcover class
 *
 * @since 1.0.0
 *
 * @param string $area
 * @param string $classes Additional CSS classes to output for this element
 */
function themify_theme_header_background( $area = 'header', $classes = '' ) {
	$class = '';
	$style = '';
	$image = null;
	$repeat = '';
	$data_bg = '';
	$post_id = get_the_ID();
	$nobg = '';
	$area_wrap = themify_get( $area . '_wrap' );
	$image_meta = '';
	$background_gallery = '';

	if ( 'header' === $area && in_array( $area_wrap, array( 'video', 'slider' ) ) ) {
		$back_key = 'styling-background-header_wrap_background-background_image-value-value';
		$mode_key = 'styling-background-header_wrap_background-background_mode-value-value';
		$nobg_key = 'styling-background-header_wrap_background-background_image-value-none';
		$header_customizer = json_decode( get_theme_mod( 'headerwrap_background' ) );

		if ( isset( $header_customizer->src ) && '' != $header_customizer->src ) {
			$image = $header_customizer->src;
			$repeat = isset( $header_customizer->style ) ? $header_customizer->style : 'fullcover';
		} elseif ( themify_check( $back_key ) ) {
			$image = themify_get( $back_key );
			$repeat = themify_check( $mode_key )? themify_get( $mode_key ): 'fullcover';
		}
		$nobg = themify_get( $nobg_key ) || ( isset( $header_customizer->noimage ) && 'noimage' === $header_customizer->noimage );

		if ( is_page() || is_singular( 'post' ) || is_singular( 'portfolio' ) ) {
			global $themify;

			if ( is_page() ) {
				$post_id = $themify->page_id;
			} else {
				$post_id = get_the_ID();
			}

			$image_meta = get_post_meta($post_id, 'background_image', true);
			if ( $image_meta ) {
				$image = $image_meta;
				$repeat_meta = get_post_meta($post_id, 'background_repeat', true);
				if ( $repeat_meta ) {
					$repeat = $repeat_meta;
				}
			}
			$background_color = get_post_meta( $post_id, 'background_color', true );
			if ( $area_wrap == 'slider' && $background_color != '' ) {
				$data_bg .= "data-bgcolor='$background_color'";
			}
			$background_gallery = get_post_meta( $post_id, 'background_gallery', true );
			if ( $gallery = ( ( $area_wrap === 'slider' ) || ( $area_wrap == '' && $background_gallery != '' ) ) ) {
				$repeat = 'fullcover header-gallery';
			} elseif ( $nobg ) {
				// Checks $image_meta because $image might have been set in customizer and we don't need to check that.
				if ( is_singular() && $image_meta ) {
					$data_bg .= " data-bg='$image'";
				}
			} elseif ( $image ) {
				$data_bg .= " data-bg='$image'";
			} else {
				$data_bg .= ' data-bg="https://themify.me/demo/themes/wp-content/uploads/2013/05/header.jpg"';
				$repeat = 'fullcover';
			}

			$video = get_post_meta( $post_id, 'video_file', true );

			if ( 'video' === $area_wrap && $video != '' ) {
				$data_bg .= " data-fullwidthvideo='$video'";
				if ( ! wp_script_is( 'themify-bigvideo-js' ) ) {
					wp_enqueue_script( 'themify-bigvideo-js' );
				}
			}
		}
	}

	if ( $repeat || $classes ) {
		$class = "class='$repeat $classes'";
	}

	if ( !empty( $style ) ) {
		$style = 'style="' . $style . '"';
	}
	
	echo "$data_bg $class $style";
}

/**
 * Returns options for header design. Used in custom panel and theme settings.
 *
 * @since 1.0.0
 *
 * @return array List of header design options.
 */
function themify_theme_header_design_options() {
	return apply_filters( 'themify_theme_header_design_options', array(
		array(
			'value' => 'default',
			'img'   => 'images/layout-icons/default.png',
			'title' => __( 'Default', 'themify' ),
			'selected' => true,
		),
		array(
			'value' => 'header-block',
			'img'   => 'images/layout-icons/header-block.png',
			'title' => __( 'Header Block', 'themify' ),
		),
		array(
			'value' => 'header-horizontal',
			'img'   => 'images/layout-icons/header-horizontal.png',
			'title' => __( 'Header Horizontal', 'themify' ),
		),
		array(
			'value' => 'header-boxed-layout',
			'img'   => 'images/layout-icons/header-boxed-layout.png',
			'title' => __( 'Header Boxed Layout', 'themify' ),
		),
		array(
			'value' => 'header-leftpane', // hides sticky header
			'img'   => 'images/layout-icons/header-leftpanel.png',
			'title' => __( 'Header Left Pane', 'themify' ),
		),
		array(
			'value' => 'header-slide-out', // hides sticky header
			'img'   => 'images/layout-icons/header-slide-out.png',
			'title' => __( 'Header Slide Out', 'themify' ),
		),
		array(
			'value' => 'header-minbar', // hides sticky header
			'img'   => 'images/layout-icons/header-minbar.png',
			'title' => __( 'Header Min Bar', 'themify' ),
		),
		array(
			'value' => 'header-boxed-compact', // hides sticky header
			'img'   => 'images/layout-icons/header-boxed-compact.png',
			'title' => __( 'Header Boxed Compact', 'themify' ),
		),
		array(
			'value' => 'header-overlay', // hides sticky header
			'img'   => 'images/layout-icons/header-overlay.png',
			'title' => __( 'Header Overlay ', 'themify' ),
		),
		array(
			'value' => 'header-rightpane', // hides sticky header
			'img'   => 'images/layout-icons/header-rightpanel.png',
			'title' => __( 'Header Right Pane ', 'themify' ),
		),
		array(
			'value' => 'none', // hides sticky header
			'img'   => 'images/layout-icons/none.png',
			'title' => __( 'No Header ', 'themify' ),
		)
	));
}

function themify_get_header_design_value(){
	static $selected = null;
	if($selected===null){
		$selected = wp_list_pluck( themify_theme_header_design_options(), 'value' );
	}
	return $selected;
}

function themify_theme_get_header_design() {
	static $header = null;
	if($header===null){
		$header = themify_area_design( 'header', array(
			'default' => '',
			'values' => themify_get_header_design_value(),
		) );
		if($header==='none'){
			$header = 'header-none';
		}
	}
	return $header;
}


/**
 * Function that checks if meta data exists and retrieves it, otherwise checks theme setting and retrieves it instead.
 * If it still doesn't exist, uses the default provided.
 *
 * @since 1.0.0
 *
 * @param string $meta
 * @param string $default
 * @param string $theme_setting
 *
 * @return mixed
 */
function themify_theme_get( $meta, $default = '', $theme_setting = '' ) {
	global $themify;
	$post_type = '';

	// If it's a singular view or a query page, try to get the post meta data first
	if ( themify_is_query_page() ) {
		// Let's check now prefixing with post type since it's a query post type page
			// Check without checking for custom post type
			$value = get_post_meta( $themify->page_id, $meta, true );
		if ( '' != $themify->query_post_type && 'post' !== $themify->query_post_type ) {
			$post_type = $themify->query_post_type . '_';
			$cpt_meta = $post_type . $meta;
			$value = get_post_meta( $themify->page_id, $cpt_meta, true );
		} else {
		}
		if ( $value && '' != $value && 'default' !== $value ) {
			return $value;
		}

	} elseif ( is_singular() ) {
		// Check first without checking for custom post type
		$value = get_post_meta( get_the_ID(), $meta, true );

		if ( $value && '' != $value && 'default' !== $value ) {
			return $value;
		}
		// Let's check now prefixing with post type
		if ( ( 'post' !== get_post_type() && 'page' !== get_post_type() ) ) {
			$post_type = get_post_type() . '_';
		}
		$cpt_meta = $post_type . $meta;
		$value = get_post_meta( get_the_ID(), $cpt_meta, true );
		if ( $value && '' != $value && 'default' != $value ) {
			return $value;
		}
	} elseif( themify_is_shop() ) {
		return themify_get( $meta, $default );
	}

	// If there is no post meta data or is '' (default), prepare to fetch theme setting
	if ( empty( $theme_setting ) ) {
		if ( themify_is_query_page() && '' != $themify->query_post_type && 'post' !== $themify->query_post_type ) {
			$post_type = $themify->query_post_type . '_';
		} elseif ( is_singular() && ( 'post' !== get_post_type() && 'page' !== get_post_type() ) ) {
			$post_type = get_post_type() . '_';
		}
		$theme_setting = 'setting-' . $post_type . $meta;
	}

	// Check theme setting (if there's a special setting like for portfolios it will be checked)
	if ( themify_check( $theme_setting ) ) {
		return themify_get( $theme_setting );
	}

	// Prepare to check non special setting stripping out the post type from setting key
	if ( 'post' !== $post_type ) {
		$theme_setting = str_replace( $post_type, '', $theme_setting );
	}
	// Check regular setting (like portfolios that rely in default layouts setting)
	if ( themify_check( $theme_setting ) ) {
		return themify_get( $theme_setting );
	}
	// No luck so return default
	return $default;
}


if ( ! function_exists( 'themify_theme_body_class' ) ) {
	/**
	 * Adds body classes for special theme features.
	 *
	 * @since 1.0.0
	 *
	 * @param $classes
	 *
	 * @return array
	 */
	function themify_theme_body_class( $classes ) {
		
		$header = themify_theme_get_header_design();
		$classes[] = $header;
		$classes[] = themify_theme_fixed_header() ? 'fixed-header' : 'no-fixed-header';

		if ( ! in_array( $header, array( 'header-leftpane', 'header-rightpane', 'header-minbar', 'header-none' ) ) ) {
			// Add transparent-header class to body if user selected it in custom panel
			if ( ( is_single() || is_page() || themify_is_shop() ) && 'transparent' === themify_get( 'header_wrap' ) ) {
				$classes[] = 'transparent-header';
			}
		}
		if ( 'header-block' === $header && 'yes' === themify_theme_get( 'full_height_header' ) ) {
			$classes[] = 'header-full-height';
		}
		
		// Exclusion classes
		if ( ! themify_theme_show_area( 'site_logo' ) ) {
			$classes[] = 'logo-off';
		}
		if ( ! themify_theme_show_area( 'site_tagline' ) ) {
			$classes[] = 'tagline-off';
		}
		if ( ! themify_theme_show_area( 'social_widget' ) ) {
			$classes[] = 'social-widget-off';
		}
		if ( ! themify_theme_show_area( 'rss' ) ) {
			$classes[] = 'rss-off';
		}
		if ( ! themify_theme_show_area( 'search_form' ) ) {
			$classes[] = 'search-off';
		}
		if ( ! themify_theme_show_area( 'menu_navigation' ) ) {
			$classes[] = 'menu-navigation-off';
		}
		if ( ! themify_theme_show_area( 'header_widgets' ) ) {
			$classes[] = 'header-widgets-off';
		}

		return $classes;
	}
}

if ( ! function_exists( 'themify_theme_show_area' ) ) {
	/**
	 * Checks whether to show a certain layout area or not.
	 *
	 * @param string $area
	 *
	 * @return bool
	 */
	function themify_theme_show_area( $area = '' ) {
		$show = true;
		switch ( $area ) {
			case 'header':
				$show = 'none' === themify_area_design( $area, array( 'values'  => wp_list_pluck( themify_theme_header_design_options(), 'value' ) ) ) ? false : true;
				break;
			default:
				if ( ( is_singular() && ! is_attachment() ) || themify_is_shop() ) {
					$exclude = themify_get( 'exclude_' . $area );
					if ( 'yes' === $exclude ) {
						$show = false;
					} elseif ( 'no' === $exclude ) {
						$show = true;
					} else {
						$show = themify_check( 'setting-exclude_' . $area ) ? false : true;
					}
				} elseif ( themify_check( 'setting-exclude_' . $area ) ) {
					$show = false;
				}
				break;
		}

		return apply_filters( "themify_theme_show_{$area}", $show );
	}
}

if ( ! function_exists( 'themify_theme_do_not_exclude_all' ) ) {
	/**
	 * Checks if all the elements in a certain area have been excluded.
	 *
	 * @since 1.0.0
	 *
	 * @param string $area
	 *
	 * @return bool
	 */
	function themify_theme_do_not_exclude_all( $area = 'header' ) {
		if ( 'mobile-menu' === $area ) {
			return themify_theme_show_area( 'search_form' ) || themify_theme_show_area( 'social_widget' ) || themify_theme_show_area( 'header_widgets' ) || themify_theme_show_area( 'rss' ) || themify_theme_show_area( 'menu_navigation' );
		} elseif ( 'header' === $area ) {
			return themify_theme_show_area( 'site_logo' ) || themify_theme_show_area( 'site_tagline' ) || themify_theme_show_area( 'search_form' ) || themify_theme_show_area( 'social_widget' ) || themify_theme_show_area( 'header_widgets' ) || themify_theme_show_area( 'rss' ) || themify_theme_show_area( 'menu_navigation' );
		}
		return false;
	}
}

function themify_theme_ajax_enqueue_scripts(){
    if(!themify_check('setting-disable_ajax')){
        wp_enqueue_script( 'themify-music-ajax', themify_enque(THEME_URI . '/js/themify.ajax.js'), array('jquery'),  wp_get_theme()->display('Version'), false );
    }
}
function themify_admin_enqueue_scripts(){
    if(isset( $_GET['page'] ) && $_GET['page']==='themify'){
        $theme_version = wp_get_theme()->display('Version');
        // Themify Media Queries CSS
        wp_enqueue_style( 'themify-admin-css', themify_enque(THEME_URI . '/admin/css/admin.css'), array(), $theme_version);
        wp_enqueue_script( 'themify-admin-js', themify_enque(THEME_URI . '/admin/js/admin.js'), array( 'jquery' ), $theme_version, true );
    }
}

/**
 * Disable Parallax header on mobile devices
 * @param bool $bool
 * @return bool
 */
function themify_disable_parallax_header_on_mobile( $bool ) {
	if ( themify_is_touch() ) $bool = false;
	return $bool;
}

/**
 * Add viewport tag for responsive layouts
 * @since 1.0.0
 */
function themify_viewport_tag() {
	echo "\n".'<meta name="viewport" content="width=device-width, initial-scale=1">'."\n";
}

if ( ! function_exists( 'themify_theme_custom_post_css' ) ) {
	/**
	 * Outputs custom post CSS at the end of a post
	 * @since 1.0.0
	 */
	function themify_theme_custom_post_css() {
		global $themify;
		if (is_singular() && in_array( get_post_type(), array( 'event', 'gallery', 'video', 'album', 'press', 'post', 'page') ) ) {
			$post_id = get_the_ID();
			if ( is_page() ) {
				if ( is_post_type_archive( 'product' ) ) {
					$entry_id = '.post-type-archive-product';
				} else {
					$entry_id = '.page-id-' . $post_id;
				}
			} else {
				$entry_id = '.postid-' . $post_id;
			}
			$headerwrap = $entry_id . ' #headerwrap';
			$site_logo = $entry_id . ' #site-logo';
			$site_description = $entry_id . ' #site-description';
			$main_nav = $entry_id . ' #main-nav';
			$social_widget = $entry_id . ' .social-widget';
			$css = array();
			$style = '';
			$rules = array(
				$headerwrap => array(),
				"$entry_id #site-logo span:after, $entry_id #headerwrap #searchform, $entry_id #main-nav .current_page_item a, $entry_id #main-nav .current-menu-item a" => array(
					array(
							'prop' => 'border-color',
							'key'  => 'headerwrap_text_color'
					),
				),
			);
			$header_type = themify_get( 'header_wrap' );
			if ( 'transparent' !== $header_type ) {
				$rules = array(
					"$entry_id #site-logo span:after, $entry_id #headerwrap #searchform, $entry_id #main-nav .current_page_item a, $entry_id #main-nav .current-menu-item a" => array(
							array(
								'prop' => 'border-color',
								'key'  => 'headerwrap_text_color'
							),
					),
				);
				if ( 'solid' === $header_type || !$header_type || 'video' === $header_type ) {
					$rules[$headerwrap] = array(
						array(
							'prop' => 'background-color',
							'key'  => 'background_color'
						),
						array(
							'prop' => 'background-image',
							'key'  => 'background_image'
						),
						array(
							'prop' => 'background-repeat',
							'key'  => 'background_repeat',
							'dependson' => array(
								'prop' => 'background-image',
								'key'  => 'background_image'
							),
						),
					);
				}
			}
			
			// Body background color, image and image repeat is not influenced by presets.
			$body_bg_color_image = array(
				array(
					'prop' => 'background-color',
					'key'  => 'body_background_color'
				),
				array(
					'prop' => 'background-image',
					'key'  => 'body_background_image'
				),
				array(
					'prop' => 'background-repeat',
					'key'  => 'body_background_repeat',
					'dependson' => array(
						'prop' => 'background-image',
						'key'  => 'body_background_image'
					),
				),
			);

			$rules["$headerwrap, $site_logo, $site_description"] = array(
				array(
					'prop' => 'color',
					'key'  => 'headerwrap_text_color'
				),
			);

			$rules["$site_logo a, $site_description a, $social_widget a, $main_nav > li > a"] = array(
				array(
					'prop' => 'color',
					'key'  => 'headerwrap_link_color'
				),
			);

			foreach ( $rules as $selector => $property ) {
				foreach ( $property as $val ) {
					$prop = $val['prop'];
					$key = $val['key'];
					if ( is_array( $key ) ) {
						if ( $prop == 'font-size' && themify_check( $key[0] ) ) {
							$css[$selector][$prop] = $prop . ': ' . themify_get( $key[0] ) . themify_get( $key[1] );
						}
					} elseif ( themify_check( $key ) && 'default' !== themify_get( $key ) ) {
						if ( $prop === 'color' || stripos( $prop, 'color' ) ) {
							if ( 'scheme_background' == $key ) {
								$header_bg_opacity = 'transparent' === themify_get( 'header_wrap' ) ? '0.9': '1';
								$css[$selector][$prop] = $prop . ':' . 'rgba(' . themify_theme_hex2rgb( themify_get( $key ) ) . ', ' . $header_bg_opacity . ')';
							} else {
								$css[$selector][$prop] = $prop . ': ' . themify_get_color( $key );
							}
						}
						elseif ( $prop === 'background-image' && 'default' !== themify_get( $key ) ) {
							$css[$selector][$prop] = $prop .': url(' . themify_get( $key ) . ')';
						}
						elseif ( $prop === 'background-repeat' && 'fullcover' === themify_get( $key ) ) {
							if ( isset( $val['dependson'] ) ) {
								if ( $val['dependson']['prop'] === 'background-image' && ( themify_check( $val['dependson']['key'] ) && 'default' !== themify_get( $val['dependson']['key'] ) ) ) {
									if( $selector === '.skin-styles' ) {
										$css['.iphone:before'] = $css[$selector];
										$css['.iphone:before']['background-size'] = 'background-size: cover; content: ""';
									}
									$css[$selector]['background-size'] = 'background-size: cover; background-attachment:fixed;';
								}
							} else {
								$css[$selector]['background-size'] = 'background-size: cover; background-attachment:fixed;';
							}
						}
						elseif ( $prop === 'font-family' ) {
							$font = themify_get( $key );
							$css[$selector][$prop] = $prop .': '. $font;
							if ( ! in_array( $font, themify_get_web_safe_font_list( true ) ) ) {
								$themify->google_fonts .= str_replace( ' ', '+', $font.'|' );
							}
						}
						else {
							$css[$selector][$prop] = $prop .': '. themify_get( $key );
						}
					}
				}
				if ( ! empty( $css[$selector] ) ) {
					global $is_iphone;
					if( !empty( $css['.iphone:before'] ) && $selector === '.skin-styles' && $is_iphone ) {
						$style .= ".iphone:before {\n\t" . implode( ";\n\t", $css[ '.iphone:before' ] ) . "\n}\n";
					} else {
						$style .= "$selector {\n\t" . implode( ";\n\t", $css[$selector] ) . "\n}\n";
					}
				}
			}

			if ( '' != $style ) {
				echo "\n<!-- Entry Style -->\n<style>\n$style</style>\n<!-- End Entry Style -->\n";
			}
		}
	}
	add_action( 'wp_head', 'themify_theme_custom_post_css', 77 );

}

/**
 * Custom Post Type Background Gallery
***************************************************************************/
class Themify_Background_Gallery{

	function __construct(){}

	function create_controller(){
		/** ID of default background gallery
		 * @var String|Number */
		$bggallery_id = $this->get_bggallery_id();
		$bggallery_order = $this->get_bggallery_order();

		$bggallery_enable = themify_get( 'header_wrap' ) === 'slider' && themify_get( 'background_gallery', '' ) != '';

		// If we still don't have a background gallery ID, do nothing.
		if( !$bggallery_id || 'default' == $bggallery_id || !$bggallery_enable ) {
			return;
		}

		$images = get_posts(array(
			'post__in' => $bggallery_id,
			'post_type' => 'attachment',
			'post_mime_type' => 'image',
			'numberposts' => -1,
			'orderby' => $bggallery_order,
			'order' => 'ASC'
		));

		if ( $images ) {
			$hide_controls = themify_check( 'header_hide_controls' ) ? 'class="tf-hide"' : '';
				echo '
				<div id="gallery-controller" ' . $hide_controls . '>
					<div class="slider">
						<ul class="slides clearfix">';
				foreach( $images as $image ){
					// Get large size for background
					$image_data = wp_get_attachment_image_src( $image->ID, apply_filters( 'themify_theme_background_gallery_image_size', 'large' ) );
					echo '<li data-bg="',$image_data[0],'"><span class="slider-dot"></span></li>';
				}
				echo '		</ul>
							<div class="carousel-nav-wrap">
								<a href="#" class="carousel-prev" style="display: block; ">&lsaquo;</a>
								<a href="#" class="carousel-next" style="display: block; ">&rsaquo;</a>
							</div>

					</div>
				</div>
				<!-- /gallery-controller -->';
		}
	}

	/**
	 * Return the background gallery ID if one of the following is found:
	 * - bg gallery defined in theme settings
	 * - bg gallery defined in Themify custom panel, either in post or page
	 * @return String|Mixed Background Gallery ID or 'default'
	 */
	function get_bggallery_id() {
		$gallery_raw = '';

		$gallery_raw = themify_get( 'background_gallery' );

		$sc_gallery = preg_replace( '#\[gallery(.*)ids="([0-9|,]*)"(.*)\]#i', '$2', $gallery_raw );

		$image_ids = explode( ',', str_replace( ' ', '', $sc_gallery ) );

		return $image_ids;
	}

	function get_bggallery_order() {
		$sc_order = false;

		$gallery_raw = themify_get( 'background_gallery' );

		if ( strpos( $gallery_raw, 'orderby' ) !== false ) {
			$sc_order = preg_replace('#\[gallery(.*)orderby="([a-zA-Z0-9]*)"(.*)\]#i', '$2', $gallery_raw);
		}

		return $sc_order ? $sc_order : 'post__in';
	}
}
// Start Background Gallery
$GLOBALS['themify_bg_gallery'] = new Themify_Background_Gallery();

/* Custom Write Panels
/***************************************************************************/

///////////////////////////////////////
// Build Write Panels
///////////////////////////////////////

if ( ! function_exists( 'themify_theme_init_types' ) ) {
	/**
	 * Initialize custom panel with its definitions
	 * Custom panel definitions are located in admin/post-type-TYPE.php
	 * @since 1.0.0
	 */
	function themify_theme_init_types() {
		// Load Themify Social Share
		require_once 'class-social-share.php';

		// Load required files for post, page and custom post types where it applies
		foreach ( array( 'post', 'page', 'event', 'gallery', 'video', 'album', 'press' ) as $type ) {
			require_once( "admin/post-type-$type.php" );
		}
		/**
		 * Navigation menus used in page custom panel to specify a custom menu for the page.
		 * @var array
		 * @since 1.2.7
		 */
		$nav_menus = array(	array( 'name' => '', 'value' => '', 'selected' => true ) );
		foreach ( get_terms( 'nav_menu' ) as $menu ) {
			$nav_menus[] = array( 'name' => $menu->name, 'value' => $menu->slug );
		}

		themify_build_write_panels( apply_filters('themify_theme_meta_boxes',
			array(
				array(
					'name'		=> __('Query Posts', 'themify'),
					'id'		=> 'query-posts',
					'options'	=> themify_theme_query_post_meta_box(),
					'pages'		=> 'page'
				),
				array(
					'name'		=> __('Query Events', 'themify'),
					'id' 		=> 'query-event',
					'options'	=> themify_theme_query_event_meta_box(),
					'pages'		=> 'page'
				),
				array(
					'name'		=> __('Query Videos', 'themify'),
					'id' 		=> 'query-video',
					'options'	=> themify_theme_query_video_meta_box(),
					'pages'		=> 'page'
				),
				array(
					'name'		=> __('Query Galleries', 'themify'),
					'id' 		=> 'query-gallery',
					'options'	=> themify_theme_query_gallery_meta_box(),
					'pages'		=> 'page'
				),
				array(
					'name'		=> __('Query Albums', 'themify'),
					'id' 		=> 'query-album',
					'options'	=> themify_theme_query_album_meta_box(),
					'pages'		=> 'page'
				),
				array(
					'name'		=> __('Query Press', 'themify'),
					'id' 		=> 'query-press',
					'options'	=> themify_theme_query_press_meta_box(),
					'pages'		=> 'page'
				),
				array(
					'name'		=> __( 'Album Tracks', 'themify' ),
					'id' 		=> 'album-tracks',
					'options'	=> themify_theme_tracks_meta_box( array( 'nav_menus' => $nav_menus ) ),
					'pages'		=> 'album'
				),
			)
		));
	}
}

function themify_theme_setup_metaboxes( $meta_boxes, $post_type ) {

	if( ! in_array( $post_type, array( 'post', 'page', 'portfolio', 'product', 'event', 'gallery', 'video', 'album', 'press' ) ) ) {
		return $meta_boxes;
	}

	/**
	 * Navigation menus used in page custom panel to specify a custom menu for the page.
	 * @since 1.0.0
	 * @var array
	 */
	$nav_menus = array(	array( 'name' => '', 'value' => '', 'selected' => true ) );
	foreach ( get_terms( 'nav_menu' ) as $menu ) {
		$nav_menus[] = array( 'name' => $menu->name, 'value' => $menu->slug );
	}

	/**
	 * Options for header design
	 * @since 1.0.0
	 * @var array
	 */
	$header_design_options = themify_theme_header_design_options();
	
	$entry_id = isset( $_GET['post'] ) ? $_GET['post'] : null;
	$background_slider = false;
	if ( $entry_id ) {
		$background_slider = ( get_post_meta( $entry_id, 'header_wrap', true ) == '' && get_post_meta( $entry_id, 'background_gallery', true ) != '' );
		$background_mode = get_post_meta( $entry_id,'background_mode', true );
	}
	if ( ! isset( $background_mode ) || ! $background_mode ) {
		$background_mode = 'fullcover';
	}

	if( $post_type === 'post' ) {
		$theme_metaboxes = array(
			array(
				'name'    => __( 'Post Options', 'themify' ),
				'id'      => 'post-options',
				'options' => themify_theme_post_meta_box( array(
					'nav_menus' => $nav_menus,
				) ),
				'pages'   => 'post'
			),
			array(
				'name'    => __( 'Post Appearance', 'themify' ),
				'id'      => 'post-theme-design',
				'options' => themify_theme_page_theme_design_meta_box( array(
					'header_design_options' => $header_design_options,
					'background_slider'		=> $background_slider,
					'background_mode'		=> $background_mode,
				) ),
				'pages'   => 'post'
			),
		);
	} elseif( $post_type === 'page' ) {
		$theme_metaboxes = array(
			array(
				'name'    => __( 'Page Options', 'themify' ),
				'id'      => 'page-options',
				'options' => themify_theme_page_meta_box( array(
					'nav_menus' => $nav_menus,
					'header_design_options' => $header_design_options,
				) ),
				'pages'   => 'page'
			),
			array(
				'name'    => __( 'Page Appearance', 'themify' ),
				'id'      => 'page-theme-design',
				'options' => themify_theme_page_theme_design_meta_box( array(
					'header_design_options' => $header_design_options,
					'background_slider'		=> $background_slider,
					'background_mode'		=> $background_mode,
				) ),
				'pages'   => 'page'
			),
		);
	} elseif( $post_type === 'event' ) {
		$theme_metaboxes = array(
			array(
				'name'    => __( 'Event Options', 'themify' ),
				'id'      => 'event-options',
				'options' => themify_theme_event_meta_box( array(
					'nav_menus' => $nav_menus,
					'header_design_options' => $header_design_options,
				) ),
				'pages'   => 'event'
			),
			array(
				'name'    => __( 'Event Appearance', 'themify' ),
				'id'      => 'event-theme-design',
				'options' => themify_theme_page_theme_design_meta_box( array(
					'header_design_options' => $header_design_options,
					'background_slider'		=> $background_slider,
					'background_mode'		=> $background_mode,
				) ),
				'pages'   => 'event'
			),
		);
	} elseif( $post_type === 'video' ) {
		$theme_metaboxes = array(
			array(
				'name'    => __( 'Video Options', 'themify' ),
				'id'      => 'video-options',
				'options' => themify_theme_video_meta_box( array(
					'nav_menus' => $nav_menus,
					'header_design_options' => $header_design_options,
				) ),
				'pages'   => 'video'
			),
			array(
				'name'    => __( 'Video Appearance', 'themify' ),
				'id'      => 'video-theme-design',
				'options' => themify_theme_page_theme_design_meta_box( array(
					'header_design_options' => $header_design_options,
					'background_slider'		=> $background_slider,
					'background_mode'		=> $background_mode,
				) ),
				'pages'   => 'video'
			),
		);
	} elseif( $post_type === 'gallery' ) {
		$theme_metaboxes = array(
			array(
				'name'    => __( 'Gallery Options', 'themify' ),
				'id'      => 'gallery-options',
				'options' => themify_theme_gallery_meta_box( array(
					'nav_menus' => $nav_menus,
					'header_design_options' => $header_design_options,
				) ),
				'pages'   => 'gallery'
			),
			array(
				'name'    => __( 'Gallery Appearance', 'themify' ),
				'id'      => 'gallery-theme-design',
				'options' => themify_theme_page_theme_design_meta_box( array(
					'header_design_options' => $header_design_options,
					'background_slider'		=> $background_slider,
					'background_mode'		=> $background_mode,
				) ),
				'pages'   => 'gallery'
			),
		);
	} elseif( $post_type === 'album' ) {
		$theme_metaboxes = array(
			array(
				'name'    => __( 'Album Options', 'themify' ),
				'id'      => 'album-options',
				'options' => themify_theme_album_meta_box( array(
					'nav_menus' => $nav_menus,
					'header_design_options' => $header_design_options,
				) ),
				'pages'   => 'album'
			),
			array(
				'name'    => __( 'Album Appearance', 'themify' ),
				'id'      => 'album-theme-design',
				'options' => themify_theme_page_theme_design_meta_box( array(
					'header_design_options' => $header_design_options,
					'background_slider'		=> $background_slider,
					'background_mode'		=> $background_mode,
				) ),
				'pages'   => 'album'
			),
		);
	} elseif( $post_type === 'press' ) {
		$theme_metaboxes = array(
			array(
				'name'    => __( 'Press Options', 'themify' ),
				'id'      => 'press-options',
				'options' => themify_theme_press_meta_box( array(
					'nav_menus' => $nav_menus,
					'header_design_options' => $header_design_options,
				) ),
				'pages'   => 'press'
			),
			array(
				'name'    => __( 'Press Appearance', 'themify' ),
				'id'      => 'press-theme-design',
				'options' => themify_theme_page_theme_design_meta_box( array(
					'header_design_options' => $header_design_options,
					'background_slider'		=> $background_slider,
					'background_mode'		=> $background_mode,
				) ),
				'pages'   => 'press'
			),
		);
	}
	
	
	return isset( $theme_metaboxes ) ? array_merge( $theme_metaboxes, $meta_boxes ) : $meta_boxes;
}
add_filter( 'themify_metabox/fields/themify-meta-boxes', 'themify_theme_setup_metaboxes', 10, 2 );

/* Custom Functions
/***************************************************************************/

///////////////////////////////////////
// Enable WordPress feature image
///////////////////////////////////////
add_theme_support( 'post-thumbnails' );

if ( ! function_exists( 'themify_register_custom_nav' ) ) {
	/**
	 * Register Custom Menu Function
	 * @since 1.0.0
	 */
	function themify_register_custom_nav() {
		register_nav_menus( array(
			'main-nav' => __( 'Main Navigation', 'themify' ),
			'footer-nav' => __( 'Footer Navigation', 'themify' ),
		));
	}
}

if ( ! function_exists( 'themify_default_main_nav' ) ) {
	/**
	 * Default Main Nav Function
	 * @since 1.0.0
	 */
	function themify_default_main_nav() {
		echo '<ul id="main-nav" class="main-nav clearfix">';
			wp_list_pages('title_li=');
		echo '</ul>';
	}
}

if ( ! function_exists( 'themify_theme_register_sidebars' ) ) {
	/**
	 * Register sidebars
	 * @since 1.0.0
	 */
	function themify_theme_register_sidebars() {
		$sidebars = array(
			array(
				'name' => __('Sidebar', 'themify'),
				'id' => 'sidebar-main',
				'before_widget' => '<div id="%1$s" class="widget %2$s">',
				'after_widget' => '</div>',
				'before_title' => '<h4 class="widgettitle">',
				'after_title' => '</h4>',
			),
			array(
				'name' => __('Social Widget', 'themify'),
				'id' => 'social-widget',
				'before_widget' => '<div id="%1$s" class="widget %2$s">',
				'after_widget' => '</div>',
				'before_title' => '<strong class="widgettitle">',
				'after_title' => '</strong>',
			)
		);
		foreach( $sidebars as $sidebar ) {
			register_sidebar( $sidebar );
		}

		// Footer Sidebars
		themify_register_grouped_widgets();
	}
}

if( ! function_exists('themify_CPT_exclude_sidebar') ) {
	/**
	 * Exclude Custom Post Types
	 */
	function themify_CPT_exclude_sidebar($CPT = array()) {
		
		$music = array('event', 'video', 'gallery', 'album', 'press');
		
		if(empty($CPT)){
			$CPT = array('post', 'page', 'attachment', 'tbuilder_layout', 'tbuilder_layout_part', 'section');
		}

		$CPT = array_merge($CPT, $music);

		return $CPT;
	}
}

if ( ! function_exists( 'themify_theme_comment' ) ) {
	/**
	 * Custom Theme Comment
	 * @param object $comment Current comment.
	 * @param array $args Parameters for comment reply link.
	 * @param int $depth Maximum comment nesting depth.
	 */
	function themify_theme_comment( $comment, $args, $depth ) {
	   $GLOBALS['comment'] = $comment; ?>

		<li id="comment-<?php comment_ID() ?>">
			<p class="comment-author">
				<?php echo get_avatar( $comment, $size = '50' ); ?>
				<cite <?php comment_class(); ?>><span <?php comment_class(); ?>><?php echo get_comment_author_link(); ?></span></cite>
				<br/>
				<small class="comment-time">
					<?php comment_date( apply_filters('themify_comment_date', '') ); ?>
					 @
					<?php comment_time( apply_filters('themify_comment_time', '') ); ?>
					<?php edit_comment_link( __('Edit', 'themify'),' [',']'); ?>
				</small>
			</p>
			<div class="commententry">
				<?php if ($comment->comment_approved == '0') : ?>
					<p><em><?php _e('Your comment is awaiting moderation.', 'themify') ?></em></p>
				<?php endif; ?>
				<?php comment_text(); ?>
			</div>
			<span class="reply">
				<?php comment_reply_link(array_merge( $args, array('add_below' => 'comment', 'depth' => $depth, 'reply_text' => __( 'Reply', 'themify' ), 'max_depth' => $args['max_depth']))) ?>
			</span>
		<?php
	}
}

if ( ! function_exists( 'themify_theme_has_submenu' ) ) {
	/**
	 * Sets custom class if menu item has a submenu.
	 * @param array $sorted_menu_items The menu items to filter.
	 * @return array The filtered menu items.
	 * @since 1.0.0
	 */
	function themify_theme_has_submenu( $sorted_menu_items ) {
		$last_top = 0;
		foreach ( $sorted_menu_items as $key => $obj ) {
			if ( 0 == $obj->menu_item_parent ) {
				$last_top = $key;
			} else {
				$sorted_menu_items[$last_top]->classes['has-sub-menu'] = 'has-sub-menu';
			}
		}
		return $sorted_menu_items;
	}
	add_filter( 'wp_nav_menu_objects', 'themify_theme_has_submenu', 10 );
}

if ( ! function_exists( 'themify_theme_likeit' ) ) {
	/**
	 * Checks liker's IP and saves it to the post if it's not already in likers list.
	 * @since 1.0.0
	 */
	function themify_theme_likeit() {
		check_ajax_referer( 'ajax_nonce', 'nonce' );

		$post_id = $_POST['post_id'];

		$ip = $_SERVER['REMOTE_ADDR'];

		$current_likers = trim( get_post_meta($post_id, 'likers', true) );

		if( isset( $current_likers ) && '' != $current_likers ) {
			$current_likers_count = count( explode( ',', $current_likers ) );
		} else {
			$current_likers_count = 0;
		}

		if( false === stripos( $current_likers, $ip ) ) {

			$save_likers = isset( $current_likers ) && '' != $current_likers? $current_likers . ',' . $ip :	$ip;

			$update_result = update_post_meta($post_id, 'likers', $save_likers);

			if ( $update_result ) {
				echo json_encode( array(
					'status' => 'new',
					'likers' => $current_likers_count + 1,
					'ip' => $ip
				) );
			} else {
				echo json_encode( array(
					'status' => 'failed',
					'ip' => $ip
				) );
			}
		} else {
			echo json_encode( array(
				'status' => 'isliker',
				'ip' => $ip
			) );
		}
		die();
	}
	add_action('wp_ajax_themify_likeit', 'themify_theme_likeit');
	add_action('wp_ajax_nopriv_themify_likeit', 'themify_theme_likeit');
}

if ( ! function_exists( 'themify_theme_get_like' ) ) {
	/**
	 * Return number of likers or 0
	 * @param bool $echo Whether to echo or just return
	 * @return string
	 * @since 1.0.0
	 */
	function themify_theme_get_like( $echo = false ) {
		if( $current_likers = themify_get('likers') ) {
			$likers = explode(',', trim($current_likers));
			$count = count($likers);
		} else {
			$count = '0';
		}
		if ( $echo ) echo $count;
		return $count;
	}
}

if ( ! function_exists( 'themify_theme_is_liker' ) ) {
	/**
	 * Check if visitor already likes this entry
	 * @param bool $echo Whether to echo or just return
	 * @return string
	 * @since 1.0.0
	 */
	function themify_theme_is_liker( $post_id ) {
		$current_likers = trim( get_post_meta($post_id, 'likers', true) );
		if( false === stripos( $current_likers, $_SERVER['REMOTE_ADDR'] ) ) {
			// IP wasn't found among likers, he doesn't like this yet
			return false;
		} else {
			// IP was found among likers, he likes this already
			return true;
		}
	}
}

if ( ! function_exists( 'themify_theme_content_width' ) ) {
	/**
	 * Checks if the single post or page has default or full width.
	 * @param array $classes
	 * @return array
	 * @since 1.0.0
	 */
	function themify_theme_content_width( $classes = array() ) {
		$classes[] = !is_search() && themify_check( 'content_width' ) ? themify_get( 'content_width' ) : 'default_width';
		$classes[] = themify_check( 'setting-fixed_header_disabled' ) ? '' : 'has-fixed-header';
		if ( ( is_single() || is_page() || themify_is_shop() ) && 'transparent' == themify_get( 'header_wrap' ) ) {
			$classes[] = 'transparent-header';
		}
		return $classes;
	}
	add_filter( 'body_class', 'themify_theme_content_width' );
}

if ( ! function_exists( 'themify_theme_featured_area_style' ) ) {
	function themify_theme_featured_area_style() {
		return themify_check('background_repeat')? themify_get('background_repeat'):'';
	}
}

/**
 * Set the fixed-header selector for the scroll highlight script
 *
 * @since 1.1.3
 */
function themify_theme_scroll_highlight_vars( $vars ) {
	$vars['fixedHeaderSelector'] = '#headerwrap.fixed-header';
	return $vars;
}
add_filter( 'themify_builder_scroll_highlight_vars', 'themify_theme_scroll_highlight_vars' );

/**
 * Allow featured areas to launch fullscreen touch gallery.
 *
 * @since 1.2.7
 *
 * @param array $vars Gallery configuration list.
 *
 * @return array
 */
function themify_theme_configure_gallery( $vars ) {
	$vars['contentImagesAreas'] .= ', .gallery-wrapper';
	return $vars;
}
add_filter( 'themify_gallery_plugins_args', 'themify_theme_configure_gallery' );

/**
 * Configure social share items.
 *
 * @since 1.4.0
 *
 * @param array $settings
 *
 * @return array
 */
function themify_theme_social_share_settings( $settings ) {
	$settings['share_html'] = apply_filters('themify_share_html', sprintf( '
			<div class="box">
				<a href="#" class="share">%s</a>
				<a href="#" class="share-icon"></a>
			</div>
			<div class="social-share clearfix">
				%s
			</div>
			<!-- .social-share -->',
			__( 'Share', 'themify' ),
			$settings['share_html']
		)
	);
	$settings['share_item'] = '.post-share';
	return $settings;
}
add_filter( 'themify_social_share_settings', 'themify_theme_social_share_settings' );

/**
 * Color animation effect for rows and header
 *
 * @since 1.4.2
 */
function themify_theme_do_animated_bg() {
	// Set colors for color animation
	$color_key = 'setting-color_stop_';
	$colors = array();
	for ( $i = 1; $i <= 7; $i++ ) {
		if ( themify_check( $color_key . $i ) ) {
			$colors[] = themify_get_color( $color_key . $i );
		}
	}
	// If there are no colors set in theme settings, use default colors
	if ( empty( $colors ) ) {
		$colors = array(
			'#33baab',
			'#e33b9e',
			'#4961d7',
			'#2ea85c',
			'#2bb8ed',
			'#dd5135',
		);
	}

	$selector = array(
		'.themify_builder_row.animated-bg'
	);
	/* when using transparent header or Background option is set, do not use the animated bg */
	if( ! ( themify_check( 'background_color' ) || themify_check( 'background_image' ) || ( themify_check( 'header_wrap' ) && 'transparent' == themify_get( 'header_wrap' ) ) ) ) {
		$selector[] = '#headerwrap';
	}

	$options = apply_filters( 'themify_animated_bg_params', array(
		'disabled' => themify_check( 'setting-color_animation_disabled' ),
		'selector' => $selector,
		'speed' => themify_check( 'setting-color_animation_speed' ) ? (int) themify_get( 'setting-color_animation_speed' ) * 1000 : '5000',
		'colors' => $colors
	) );

	if( $options['disabled'] )
		return;

	$css_steps = '';
	foreach( $options['colors'] as $key => $val ) {
		$css_steps .= ( $key == 0 ? '0' : 100 / $key ) . '% { background-color: ' . $val . '; }' . "\n";
	}
	$selector = implode( ',', $options['selector'] );
	$speed = $options['speed'] * count( $colors ); // @note: in CSS the speed for the entire duration of the animation, so so we need to multiply the number of slides

	echo"
	<style type=\"text/css\">
	@-webkit-keyframes themifyAnimatedBG {
		{$css_steps}
	}
	@keyframes themifyAnimatedBG {
		{$css_steps}
	}
	{$selector} {
		-webkit-animation: themifyAnimatedBG {$speed}ms infinite alternate;
		animation: themifyAnimatedBG {$speed}ms infinite alternate;
	}
	</style>
	";
}
add_action( 'wp_head', 'themify_theme_do_animated_bg' );


/**
 * Get event repeat date of post
 *
 * @return string
 */
function themify_theme_get_repeat_date( $type, $number,$date, $time ) {
        $result = '';
        switch($type){
            case 'day':
                $result = sprintf(_n('Every day','Every %s days',$number,'themify'),$number);
            break;
            case 'week':
                $result = sprintf(_n('Every week on %2$s','Every %s weeks on %s',$number,'themify'),$number,  date_i18n('l',  strtotime($date)));
            break;
            case 'year':
                $result = sprintf(_n('Every year on %2$s','Every %s years on %s',$number,'themify'),$number,  date_i18n('M d',  strtotime($date)));
            break;
        }
        if($result && $time){
            $result.=_x( ' @ ', 'Connector between date and time (with spaces around itself) in event date and time.', 'themify' ).date_i18n( get_option( 'time_format' ), strtotime( $time ) ) ;
        }
        return apply_filters('themify_event_date_repeat',$result,$type, $number,$date, $time);
}

/**
 * Deprecated function, kept for backwards compatibility
 */
function themify_theme_menu_nav() {
	themify_menu_nav();
}
function themify_is_ajax_response(){
    static $load = NULL;
    if(is_null($load)){
        $load = isset($_REQUEST['themify_ajax']) && !is_admin() && TFCache::is_ajax();
    }
    return  $load; !empty($_REQUEST['themify_load']);
}
function themify_load_content_only(){
    return  !themify_is_ajax_response() || (themify_is_ajax_response() && !empty($_REQUEST['themify_load']));
}
function themify_ajax_response(){
    if(themify_is_ajax_response()){
        
        add_filter('themify_builder_is_frontend_editor','__return_false');
        add_action( 'themify_footer_data', 'themify_render_ajax_files',100);
       
    }
}

function themify_render_ajax_files(){
    global $wp_scripts,$wp_styles; 
    $response_js = array('queue'=>$wp_scripts->queue,'registered'=>$wp_scripts->registered);
    echo '<script type="text/javascript" defer>themify_js_files='.  json_encode($response_js).'</script>';
}

function themify_preprocess_comment(){
    if(!empty($_POST['data'])){
        $response = array();
        $comment = wp_handle_comment_submission( wp_unslash( $_POST['data'] ) );
        if ( is_wp_error( $comment ) ) {
            $error = $comment->get_error_message();
            $response['error'] = 1;
            $known_errors = array(
                'require_name_email'=>'author,email',
                'require_valid_email'=>'email',
                'comment_author_column_length'=>'author',
                'comment_author_email_column_length'=>'email',
                'comment_author_url_column_length'=>'url',
                'require_valid_comment'=>'comment',
                'comment_content_column_length'=>'comment'
            );
            $key = $comment->get_error_code();
            $response['data']['val'] = $comment->get_error_message();
            if(isset($known_errors[$key])){
                $response['data']['id']=$known_errors[$key];
            }
        }
        else{
            
            $user = wp_get_current_user();
            do_action( 'set_comment_cookies', $comment, $user );
            $response['success'] = 1;
            $comment_post_ID = $_POST['data']['comment_post_ID'];
            global $post, $product;
            wp_update_comment_count($comment_post_ID);
            $post = get_post( $comment_post_ID );
            query_posts(array('p'=>$post->ID,'post_type'=>$post->post_type));
            if(class_exists('WC_Product')){
                $product = new WC_Product($post);
            }
            ob_start();
            comments_template();
            $response['data'] = ob_get_contents();
            ob_end_clean();
        }
        echo wp_json_encode($response);
    }
    wp_die();
}
add_action('wp_ajax_themify_comment', 'themify_preprocess_comment');

add_action('wp_ajax_nopriv_themify_comment', 'themify_preprocess_comment');
function themify_theme_fixed_header() {
        static $fixed = NULL;
        if(is_null($fixed)){
            $header = themify_area_design( 'header', array('values' => themify_get_header_design_value(), ) );
            if ( in_array( $header, array( 'header-leftpane', 'header-rightpane', 'header-minbar', 'none' ) ) ) {
                    $fixed = '';
                    return $fixed;
            }
            if ( is_singular( array( 'post', 'page', 'portfolio' ) ) ) {
                    $fixed_header_field = themify_get( 'fixed_header' );
                    if ( 'yes' == $fixed_header_field ) {
                        $fixed = 'fixed-header';
                        return $fixed;
                    } elseif ( 'no' == $fixed_header_field ) {
                            $fixed = '';
                            return $fixed;
                    }
            }
            $fixed = themify_check( 'setting-fixed_header_disabled' ) ? '' : 'fixed-header';
        }
        return $fixed;
}

function themify_theme_sticky_logo(){
     if(themify_theme_fixed_header()){
        global $themify_customizer;
        $logo = json_decode($themify_customizer->get_cached_mod('sticky_header_imageselect'));
        return isset($logo->src) && '' != $logo->src?$logo:false;
     }
     else{
         return false;
     }
}
if (is_admin()) {
    add_action('admin_enqueue_scripts', 'themify_admin_script_style');

    function themify_admin_script_style() {
        wp_enqueue_script('themify-admin-script', themify_enque(THEME_URI . '/admin/js/admin.js'));
    }
}

// Album Tracks Backwards Compatibility
function themify_album_tracks_backwards() {
	$albums = get_posts( array( 'post_type' => 'album', 'numberposts' => -1 ) );
	
	if( ! empty( $albums ) && ! get_option( '__themify_backwards_album_tracks', 0 ) ) {
		foreach( $albums as $album ) {
			$id = $album->ID;
			$old_tracks = array();

			for ( $track = 1; $track <= apply_filters( 'themify_theme_number_of_tracks', 18 ); $track++ ) {
				$old_track_name = get_post_meta( $id, 'track_name_' . $track, true );
				$old_track_file = get_post_meta( $id, 'track_file_' . $track, true );

				if( ! empty( $old_track_name ) || ! empty( $old_track_file ) ) {
					$old_tracks[] = array(
						'name' => ! empty( $old_track_name ) ? $old_track_name : '',
						'file' => ! empty( $old_track_file ) ? $old_track_file : '',
					);
				}
			}

			if( ! empty( $old_tracks ) ) {
				update_post_meta( $id, 'album_tracks', $old_tracks );
			}
		}

		update_option( '__themify_backwards_album_tracks', 1 );
	}
}
add_action( 'init', 'themify_album_tracks_backwards' );

function themif_is_event_expired( $event_end ) {
	$event_end = strtotime( $event_end );

	return ! empty( $event_end ) && is_numeric( $event_end ) ? time() > $event_end : false;
}

if ( ! function_exists( 'themify_event_permalinks' ) ) {

	/**
	 * Call Each post type custom permalink
	 * @return string
	 *
	 */
	function themify_custom_permalinks(){

		$html = '';
		$html .= themify_album_slug();
		$html .= themify_event_slug();
		$html .= themify_gallery_slug();
		$html .= themify_press_slug();
		$html .= themify_video_slug();
		$html .= '<p>
				<span>' . __('Use only lowercase letters, numbers, underscores and dashes.', 'themify') . '</span>
				<span>' . sprintf(__('After changing this, go to <a href="%s">permalinks</a> and click "Save changes" to refresh them.', 'themify'), admin_url('options-permalink.php#submit')) . '</span>
			</p>';

		return $html;
	}
}